==> kubernetes-model-gatewayapi-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPBackendRefFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPBackendRefFluent<A extends HTTPBackendRefFluent<A>> extends Fluent<A>{
  public A addToFilters(Integer index,HTTPRouteFilter item);
  public A setToFilters(Integer index,HTTPRouteFilter item);
  public A addToFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... items);
  public A addAllToFilters(Collection<HTTPRouteFilter> items);
  public A removeFromFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... items);
  public A removeAllFromFilters(Collection<HTTPRouteFilter> items);
  public A removeMatchingFromFilters(Predicate<HTTPRouteFilterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFilters instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRouteFilter> getFilters();
  public List<HTTPRouteFilter> buildFilters();
  public HTTPRouteFilter buildFilter(Integer index);
  public HTTPRouteFilter buildFirstFilter();
  public HTTPRouteFilter buildLastFilter();
  public HTTPRouteFilter buildMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public Boolean hasMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public A withFilters(List<HTTPRouteFilter> filters);
  public A withFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... filters);
  public Boolean hasFilters();
  public HTTPBackendRefFluent.FiltersNested<A> addNewFilter();
  public HTTPBackendRefFluent.FiltersNested<A> addNewFilterLike(HTTPRouteFilter item);
  public HTTPBackendRefFluent.FiltersNested<A> setNewFilterLike(Integer index,HTTPRouteFilter item);
  public HTTPBackendRefFluent.FiltersNested<A> editFilter(Integer index);
  public HTTPBackendRefFluent.FiltersNested<A> editFirstFilter();
  public HTTPBackendRefFluent.FiltersNested<A> editLastFilter();
  public HTTPBackendRefFluent.FiltersNested<A> editMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public String getGroup();
  public A withGroup(String group);
  public Boolean hasGroup();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public Integer getWeight();
  public A withWeight(Integer weight);
  public Boolean hasWeight();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FiltersNested<N> extends Nested<N>,HTTPRouteFilterFluent<HTTPBackendRefFluent.FiltersNested<N>>{
    public N and();
    public N endFilter();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPBackendRefFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPBackendRefFluent<A extends HTTPBackendRefFluent<A>> extends Fluent<A>{
  public A addToFilters(int index,HTTPRouteFilter item);
  public A setToFilters(int index,HTTPRouteFilter item);
  public A addToFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... items);
  public A addAllToFilters(Collection<HTTPRouteFilter> items);
  public A removeFromFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... items);
  public A removeAllFromFilters(Collection<HTTPRouteFilter> items);
  public A removeMatchingFromFilters(Predicate<HTTPRouteFilterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFilters instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRouteFilter> getFilters();
  public List<HTTPRouteFilter> buildFilters();
  public HTTPRouteFilter buildFilter(int index);
  public HTTPRouteFilter buildFirstFilter();
  public HTTPRouteFilter buildLastFilter();
  public HTTPRouteFilter buildMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public Boolean hasMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public A withFilters(List<HTTPRouteFilter> filters);
  public A withFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... filters);
  public Boolean hasFilters();
  public HTTPBackendRefFluent.FiltersNested<A> addNewFilter();
  public HTTPBackendRefFluent.FiltersNested<A> addNewFilterLike(HTTPRouteFilter item);
  public HTTPBackendRefFluent.FiltersNested<A> setNewFilterLike(int index,HTTPRouteFilter item);
  public HTTPBackendRefFluent.FiltersNested<A> editFilter(int index);
  public HTTPBackendRefFluent.FiltersNested<A> editFirstFilter();
  public HTTPBackendRefFluent.FiltersNested<A> editLastFilter();
  public HTTPBackendRefFluent.FiltersNested<A> editMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public String getGroup();
  public A withGroup(String group);
  public Boolean hasGroup();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public Integer getWeight();
  public A withWeight(Integer weight);
  public Boolean hasWeight();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FiltersNested<N> extends Nested<N>,HTTPRouteFilterFluent<HTTPBackendRefFluent.FiltersNested<N>>{
    public N and();
    public N endFilter();
    
  }
  
}
